"""MediaTracker: Init"""
import logging

from aiohttp import ClientResponse
from typing import List

from .objects.base import MediaTrackerBase
from .objects.config import MediaTrackerConfig
from .objects.item import MediaTrackerItem
from .objects.calendar import MediaTrackerCalendar
from .client import MediaTrackerClient


class MediaTracker(MediaTrackerBase):
    """Interacting with MediaTracker API."""

    logger = logging.getLogger(__name__)

    def __init__(self, client: "MediaTrackerClient", host: str, token: str) -> None:
        """Initialize the appliance."""
        self._client = client
        self._host = host
        self._token = token
        self._config = MediaTrackerConfig
        self._items: List[MediaTrackerItem] = []
        self._calendar: List[MediaTrackerCalendar] = []
        self._entities = [
            {
                "key": "audiobook",
                "name": "Audiobooks",
            },
            {
                "key": "book",
                "name": "Books",
            },
            {
                "key": "movie",
                "name": "Movies",
            },
            {
                "key": "tv",
                "name": "TV Series",
            },
            {
                "key": "video_game",
                "name": "Games",
            },
        ]

    @property
    def host(self) -> str:
        return self._host

    @property
    def token(self) -> str:
        return self._token

    @property
    def items(self) -> List[MediaTrackerItem]:
        return self._items

    @property
    def calendar(self) -> List[MediaTrackerCalendar]:
        return self._calendar

    @property
    def config(self) -> dict:
        return self._config

    @property
    def entities(self) -> dict:
        return self._entities

    async def fetch(self) -> None:
        """Fetch data from MediaTracker."""
        data: dict = {}
        data["config"] = await self.get_config()
        data["items"] = await self.get_items()
        data["entities"] = self.entities
        data["calendar"] = self.calendar

        return data

    async def get_config(self) -> MediaTrackerConfig:
        """Get Config."""
        response: ClientResponse = await self._client.get(
            f"http://{self._host}/api/configuration?token={self._token}"
        )
        json = await response.json()
        self.logger.debug(json)
        config = [MediaTrackerConfig(self._client, json)]

        return config

    async def get_items(self) -> MediaTrackerItem:
        """Get Items."""
        response: ClientResponse = await self._client.get(
            f"http://{self._host}/api/items?token={self._token}"
        )
        json = await response.json()
        self.logger.debug(json)

        self._items = [MediaTrackerItem(self._client, item) for item in json or []]
        self._items_dict: dict = {}
        for item in self._items:
            self._items_dict[item.id] = item

    async def get_by_media_type(self, media_type) -> MediaTrackerItem:
        """Get Media."""
        response: ClientResponse = await self._client.get(
            f"http://{self._host}/api/items?mediaType={media_type}&token={self._token}"
        )
        json = await response.json()
        self.logger.debug(json)

        self._items = [MediaTrackerItem(self._client, item) for item in json or []]
        self._items_dict: dict = {}
        for item in self._items:
            self._items_dict[item.id] = item



"""
Class object for MediaTrackerCalendar
Documentation:

Generated by generator/generator.py - 2023-05-10 20:22:42.735267
"""
from .base import MediaTrackerBase, MediaTrackerBaseClient


class Mediaitem(MediaTrackerBase):
    @property
    def id(self):
        return self.attributes.get("id", None)

    @property
    def title(self):
        return self.attributes.get("title", "")

    @property
    def releaseDate(self):
        return self.attributes.get("releaseDate", "")

    @property
    def slug(self):
        return self.attributes.get("slug", "")

    @property
    def mediaType(self):
        return self.attributes.get("mediaType", "")

    @property
    def seen(self):
        return self.attributes.get("seen", True)


class Episode(MediaTrackerBase):
    @property
    def id(self):
        return self.attributes.get("id", None)

    @property
    def title(self):
        return self.attributes.get("title", "")

    @property
    def episodeNumber(self):
        return self.attributes.get("episodeNumber", None)

    @property
    def seasonNumber(self):
        return self.attributes.get("seasonNumber", None)

    @property
    def releaseDate(self):
        return self.attributes.get("releaseDate", "")

    @property
    def isSpecialEpisode(self):
        return self.attributes.get("isSpecialEpisode", True)

    @property
    def seen(self):
        return self.attributes.get("seen", True)


class MediaTrackerCalendar(MediaTrackerBaseClient):
    @property
    def releaseDate(self):
        return self.attributes.get("releaseDate", "")

    @property
    def mediaItem(self):
        return Mediaitem(self.attributes.get("mediaItem", {}))

    @property
    def episode(self):
        return Episode(self.attributes.get("episode", {}))



"""
Class object for MediaTrackerItem
Documentation:

Generated by generator/generator.py - 2023-05-09 20:21:34.332818
"""
from .base import MediaTrackerBase, MediaTrackerBaseClient


class Seenhistory(MediaTrackerBase):
    @property
    def id(self):
        return self.attributes.get("id", None)

    @property
    def date(self):
        return self.attributes.get("date", None)

    @property
    def mediaItemId(self):
        return self.attributes.get("mediaItemId", None)

    @property
    def episodeId(self):
        return self.attributes.get("episodeId", None)

    @property
    def userId(self):
        return self.attributes.get("userId", None)

    @property
    def duration(self):
        return self.attributes.get("duration", None)


class EpisodesUserrating(MediaTrackerBase):
    @property
    def id(self):
        return self.attributes.get("id", None)

    @property
    def mediaItemId(self):
        return self.attributes.get("mediaItemId", None)

    @property
    def date(self):
        return self.attributes.get("date", None)

    @property
    def userId(self):
        return self.attributes.get("userId", None)

    @property
    def rating(self):
        return self.attributes.get("rating", None)

    @property
    def review(self):
        return self.attributes.get("review", "")

    @property
    def episodeId(self):
        return self.attributes.get("episodeId", None)

    @property
    def seasonId(self):
        return self.attributes.get("seasonId", None)


class Seenhistory(MediaTrackerBase):
    @property
    def id(self):
        return self.attributes.get("id", None)

    @property
    def date(self):
        return self.attributes.get("date", None)

    @property
    def mediaItemId(self):
        return self.attributes.get("mediaItemId", None)

    @property
    def episodeId(self):
        return self.attributes.get("episodeId", None)

    @property
    def userId(self):
        return self.attributes.get("userId", None)

    @property
    def duration(self):
        return self.attributes.get("duration", None)


class EpisodesTvshowUserrating(MediaTrackerBase):
    @property
    def id(self):
        return self.attributes.get("id", None)

    @property
    def mediaItemId(self):
        return self.attributes.get("mediaItemId", None)

    @property
    def date(self):
        return self.attributes.get("date", None)

    @property
    def userId(self):
        return self.attributes.get("userId", None)

    @property
    def rating(self):
        return self.attributes.get("rating", None)

    @property
    def review(self):
        return self.attributes.get("review", "")

    @property
    def episodeId(self):
        return self.attributes.get("episodeId", None)

    @property
    def seasonId(self):
        return self.attributes.get("seasonId", None)


class EpisodesTvshow(MediaTrackerBase):
    @property
    def id(self):
        return self.attributes.get("id", None)

    @property
    def releaseDate(self):
        return self.attributes.get("releaseDate", "")

    @property
    def slug(self):
        return self.attributes.get("slug", "")

    @property
    def numberOfEpisodes(self):
        return self.attributes.get("numberOfEpisodes", None)

    @property
    def poster(self):
        return self.attributes.get("poster", "")

    @property
    def title(self):
        return self.attributes.get("title", "")

    @property
    def tmdbId(self):
        return self.attributes.get("tmdbId", None)

    @property
    def tvdbId(self):
        return self.attributes.get("tvdbId", None)

    @property
    def traktId(self):
        return self.attributes.get("traktId", None)

    @property
    def tvmazeId(self):
        return self.attributes.get("tvmazeId", None)

    @property
    def backdrop(self):
        return self.attributes.get("backdrop", "")

    @property
    def developer(self):
        return self.attributes.get("developer", "")

    @property
    def genres(self):
        return self.attributes.get("genres", [])

    @property
    def igdbId(self):
        return self.attributes.get("igdbId", None)

    @property
    def imdbId(self):
        return self.attributes.get("imdbId", "")

    @property
    def audibleId(self):
        return self.attributes.get("audibleId", "")

    @property
    def lastTimeUpdated(self):
        return self.attributes.get("lastTimeUpdated", None)

    @property
    def mediaType(self):
        return self.attributes.get("mediaType", "")

    @property
    def network(self):
        return self.attributes.get("network", "")

    @property
    def numberOfSeasons(self):
        return self.attributes.get("numberOfSeasons", None)

    @property
    def openlibraryId(self):
        return self.attributes.get("openlibraryId", "")

    @property
    def originalTitle(self):
        return self.attributes.get("originalTitle", "")

    @property
    def overview(self):
        return self.attributes.get("overview", "")

    @property
    def platform(self):
        return self.attributes.get("platform", [])

    @property
    def tmdbRating(self):
        return self.attributes.get("tmdbRating", None)

    @property
    def runtime(self):
        return self.attributes.get("runtime", None)

    @property
    def source(self):
        return self.attributes.get("source", "")

    @property
    def status(self):
        return self.attributes.get("status", "")

    @property
    def url(self):
        return self.attributes.get("url", "")

    @property
    def needsDetails(self):
        return self.attributes.get("needsDetails", True)

    @property
    def authors(self):
        return self.attributes.get("authors", [])

    @property
    def narrators(self):
        return self.attributes.get("narrators", [])

    @property
    def language(self):
        return self.attributes.get("language", "")

    @property
    def goodreadsId(self):
        return self.attributes.get("goodreadsId", None)

    @property
    def numberOfPages(self):
        return self.attributes.get("numberOfPages", None)

    @property
    def audibleCountryCode(self):
        return self.attributes.get("audibleCountryCode", "")

    @property
    def isSearchResult(self):
        return self.attributes.get("isSearchResult", True)

    @property
    def hasDetails(self):
        return self.attributes.get("hasDetails", True)

    @property
    def posterSmall(self):
        return self.attributes.get("posterSmall", "")

    @property
    def seenHistory(self):
        return [Seenhistory(x) for x in self.attributes.get("seenHistory", [])]

    @property
    def unseenEpisodesCount(self):
        return self.attributes.get("unseenEpisodesCount", None)

    @property
    def userRating(self):
        return EpisodesTvshowUserrating(self.attributes.get("userRating", {}))

    @property
    def upcomingEpisode(self):
        return self.attributes.get("upcomingEpisode", "")

    @property
    def lastAiredEpisode(self):
        return self.attributes.get("lastAiredEpisode", "")

    @property
    def nextAiring(self):
        return self.attributes.get("nextAiring", "")

    @property
    def lastAiring(self):
        return self.attributes.get("lastAiring", "")

    @property
    def onWatchlist(self):
        return self.attributes.get("onWatchlist", True)

    @property
    def lastSeenAt(self):
        return self.attributes.get("lastSeenAt", None)

    @property
    def seen(self):
        return self.attributes.get("seen", True)

    @property
    def firstUnwatchedEpisode(self):
        return self.attributes.get("firstUnwatchedEpisode", "")

    @property
    def progress(self):
        return self.attributes.get("progress", None)

    @property
    def totalRuntime(self):
        return self.attributes.get("totalRuntime", None)


class Episodes(MediaTrackerBase):
    @property
    def id(self):
        return self.attributes.get("id", None)

    @property
    def title(self):
        return self.attributes.get("title", "")

    @property
    def description(self):
        return self.attributes.get("description", "")

    @property
    def episodeNumber(self):
        return self.attributes.get("episodeNumber", None)

    @property
    def seasonNumber(self):
        return self.attributes.get("seasonNumber", None)

    @property
    def releaseDate(self):
        return self.attributes.get("releaseDate", "")

    @property
    def tvShowId(self):
        return self.attributes.get("tvShowId", None)

    @property
    def seasonId(self):
        return self.attributes.get("seasonId", None)

    @property
    def tmdbId(self):
        return self.attributes.get("tmdbId", None)

    @property
    def imdbId(self):
        return self.attributes.get("imdbId", "")

    @property
    def runtime(self):
        return self.attributes.get("runtime", None)

    @property
    def seenHistory(self):
        return [Seenhistory(x) for x in self.attributes.get("seenHistory", [])]

    @property
    def userRating(self):
        return EpisodesUserrating(self.attributes.get("userRating", {}))

    @property
    def lastSeenAt(self):
        return self.attributes.get("lastSeenAt", None)

    @property
    def seasonAndEpisodeNumber(self):
        return self.attributes.get("seasonAndEpisodeNumber", None)

    @property
    def seen(self):
        return self.attributes.get("seen", True)

    @property
    def tvShow(self):
        return EpisodesTvshow(self.attributes.get("tvShow", {}))

    @property
    def isSpecialEpisode(self):
        return self.attributes.get("isSpecialEpisode", True)

    @property
    def tvdbId(self):
        return self.attributes.get("tvdbId", None)

    @property
    def traktId(self):
        return self.attributes.get("traktId", None)

    @property
    def onWatchlist(self):
        return self.attributes.get("onWatchlist", True)


class SeasonsUserrating(MediaTrackerBase):
    @property
    def id(self):
        return self.attributes.get("id", None)

    @property
    def mediaItemId(self):
        return self.attributes.get("mediaItemId", None)

    @property
    def date(self):
        return self.attributes.get("date", None)

    @property
    def userId(self):
        return self.attributes.get("userId", None)

    @property
    def rating(self):
        return self.attributes.get("rating", None)

    @property
    def review(self):
        return self.attributes.get("review", "")

    @property
    def episodeId(self):
        return self.attributes.get("episodeId", None)

    @property
    def seasonId(self):
        return self.attributes.get("seasonId", None)


class Seasons(MediaTrackerBase):
    @property
    def id(self):
        return self.attributes.get("id", None)

    @property
    def description(self):
        return self.attributes.get("description", "")

    @property
    def numberOfEpisodes(self):
        return self.attributes.get("numberOfEpisodes", None)

    @property
    def poster(self):
        return self.attributes.get("poster", "")

    @property
    def releaseDate(self):
        return self.attributes.get("releaseDate", "")

    @property
    def tvShowId(self):
        return self.attributes.get("tvShowId", None)

    @property
    def tmdbId(self):
        return self.attributes.get("tmdbId", None)

    @property
    def title(self):
        return self.attributes.get("title", "")

    @property
    def seasonNumber(self):
        return self.attributes.get("seasonNumber", None)

    @property
    def tvmazeId(self):
        return self.attributes.get("tvmazeId", None)

    @property
    def episodes(self):
        return [Episodes(x) for x in self.attributes.get("episodes", [])]

    @property
    def userRating(self):
        return SeasonsUserrating(self.attributes.get("userRating", {}))

    @property
    def seen(self):
        return self.attributes.get("seen", True)

    @property
    def posterSmall(self):
        return self.attributes.get("posterSmall", "")

    @property
    def isSpecialSeason(self):
        return self.attributes.get("isSpecialSeason", True)

    @property
    def tvdbId(self):
        return self.attributes.get("tvdbId", None)

    @property
    def traktId(self):
        return self.attributes.get("traktId", None)

    @property
    def onWatchlist(self):
        return self.attributes.get("onWatchlist", True)

    @property
    def totalRuntime(self):
        return self.attributes.get("totalRuntime", None)

    @property
    def lastSeenAt(self):
        return self.attributes.get("lastSeenAt", None)

    @property
    def unseenEpisodesCount(self):
        return self.attributes.get("unseenEpisodesCount", None)


class Seenhistory(MediaTrackerBase):
    @property
    def id(self):
        return self.attributes.get("id", None)

    @property
    def date(self):
        return self.attributes.get("date", None)

    @property
    def mediaItemId(self):
        return self.attributes.get("mediaItemId", None)

    @property
    def episodeId(self):
        return self.attributes.get("episodeId", None)

    @property
    def userId(self):
        return self.attributes.get("userId", None)

    @property
    def duration(self):
        return self.attributes.get("duration", None)


class Userrating(MediaTrackerBase):
    @property
    def id(self):
        return self.attributes.get("id", None)

    @property
    def mediaItemId(self):
        return self.attributes.get("mediaItemId", None)

    @property
    def date(self):
        return self.attributes.get("date", None)

    @property
    def userId(self):
        return self.attributes.get("userId", None)

    @property
    def rating(self):
        return self.attributes.get("rating", None)

    @property
    def review(self):
        return self.attributes.get("review", "")

    @property
    def episodeId(self):
        return self.attributes.get("episodeId", None)

    @property
    def seasonId(self):
        return self.attributes.get("seasonId", None)


class Seenhistory(MediaTrackerBase):
    @property
    def id(self):
        return self.attributes.get("id", None)

    @property
    def date(self):
        return self.attributes.get("date", None)

    @property
    def mediaItemId(self):
        return self.attributes.get("mediaItemId", None)

    @property
    def episodeId(self):
        return self.attributes.get("episodeId", None)

    @property
    def userId(self):
        return self.attributes.get("userId", None)

    @property
    def duration(self):
        return self.attributes.get("duration", None)


class UpcomingepisodeUserrating(MediaTrackerBase):
    @property
    def id(self):
        return self.attributes.get("id", None)

    @property
    def mediaItemId(self):
        return self.attributes.get("mediaItemId", None)

    @property
    def date(self):
        return self.attributes.get("date", None)

    @property
    def userId(self):
        return self.attributes.get("userId", None)

    @property
    def rating(self):
        return self.attributes.get("rating", None)

    @property
    def review(self):
        return self.attributes.get("review", "")

    @property
    def episodeId(self):
        return self.attributes.get("episodeId", None)

    @property
    def seasonId(self):
        return self.attributes.get("seasonId", None)


class Seenhistory(MediaTrackerBase):
    @property
    def id(self):
        return self.attributes.get("id", None)

    @property
    def date(self):
        return self.attributes.get("date", None)

    @property
    def mediaItemId(self):
        return self.attributes.get("mediaItemId", None)

    @property
    def episodeId(self):
        return self.attributes.get("episodeId", None)

    @property
    def userId(self):
        return self.attributes.get("userId", None)

    @property
    def duration(self):
        return self.attributes.get("duration", None)


class UpcomingepisodeTvshowUserrating(MediaTrackerBase):
    @property
    def id(self):
        return self.attributes.get("id", None)

    @property
    def mediaItemId(self):
        return self.attributes.get("mediaItemId", None)

    @property
    def date(self):
        return self.attributes.get("date", None)

    @property
    def userId(self):
        return self.attributes.get("userId", None)

    @property
    def rating(self):
        return self.attributes.get("rating", None)

    @property
    def review(self):
        return self.attributes.get("review", "")

    @property
    def episodeId(self):
        return self.attributes.get("episodeId", None)

    @property
    def seasonId(self):
        return self.attributes.get("seasonId", None)


class UpcomingepisodeTvshow(MediaTrackerBase):
    @property
    def id(self):
        return self.attributes.get("id", None)

    @property
    def releaseDate(self):
        return self.attributes.get("releaseDate", "")

    @property
    def slug(self):
        return self.attributes.get("slug", "")

    @property
    def numberOfEpisodes(self):
        return self.attributes.get("numberOfEpisodes", None)

    @property
    def poster(self):
        return self.attributes.get("poster", "")

    @property
    def title(self):
        return self.attributes.get("title", "")

    @property
    def tmdbId(self):
        return self.attributes.get("tmdbId", None)

    @property
    def tvdbId(self):
        return self.attributes.get("tvdbId", None)

    @property
    def traktId(self):
        return self.attributes.get("traktId", None)

    @property
    def tvmazeId(self):
        return self.attributes.get("tvmazeId", None)

    @property
    def backdrop(self):
        return self.attributes.get("backdrop", "")

    @property
    def developer(self):
        return self.attributes.get("developer", "")

    @property
    def genres(self):
        return self.attributes.get("genres", [])

    @property
    def igdbId(self):
        return self.attributes.get("igdbId", None)

    @property
    def imdbId(self):
        return self.attributes.get("imdbId", "")

    @property
    def audibleId(self):
        return self.attributes.get("audibleId", "")

    @property
    def lastTimeUpdated(self):
        return self.attributes.get("lastTimeUpdated", None)

    @property
    def mediaType(self):
        return self.attributes.get("mediaType", "")

    @property
    def network(self):
        return self.attributes.get("network", "")

    @property
    def numberOfSeasons(self):
        return self.attributes.get("numberOfSeasons", None)

    @property
    def openlibraryId(self):
        return self.attributes.get("openlibraryId", "")

    @property
    def originalTitle(self):
        return self.attributes.get("originalTitle", "")

    @property
    def overview(self):
        return self.attributes.get("overview", "")

    @property
    def platform(self):
        return self.attributes.get("platform", [])

    @property
    def tmdbRating(self):
        return self.attributes.get("tmdbRating", None)

    @property
    def runtime(self):
        return self.attributes.get("runtime", None)

    @property
    def source(self):
        return self.attributes.get("source", "")

    @property
    def status(self):
        return self.attributes.get("status", "")

    @property
    def url(self):
        return self.attributes.get("url", "")

    @property
    def needsDetails(self):
        return self.attributes.get("needsDetails", True)

    @property
    def authors(self):
        return self.attributes.get("authors", [])

    @property
    def narrators(self):
        return self.attributes.get("narrators", [])

    @property
    def language(self):
        return self.attributes.get("language", "")

    @property
    def goodreadsId(self):
        return self.attributes.get("goodreadsId", None)

    @property
    def numberOfPages(self):
        return self.attributes.get("numberOfPages", None)

    @property
    def audibleCountryCode(self):
        return self.attributes.get("audibleCountryCode", "")

    @property
    def isSearchResult(self):
        return self.attributes.get("isSearchResult", True)

    @property
    def hasDetails(self):
        return self.attributes.get("hasDetails", True)

    @property
    def posterSmall(self):
        return self.attributes.get("posterSmall", "")

    @property
    def seenHistory(self):
        return [Seenhistory(x) for x in self.attributes.get("seenHistory", [])]

    @property
    def unseenEpisodesCount(self):
        return self.attributes.get("unseenEpisodesCount", None)

    @property
    def userRating(self):
        return UpcomingepisodeTvshowUserrating(self.attributes.get("userRating", {}))

    @property
    def upcomingEpisode(self):
        return self.attributes.get("upcomingEpisode", "")

    @property
    def lastAiredEpisode(self):
        return self.attributes.get("lastAiredEpisode", "")

    @property
    def nextAiring(self):
        return self.attributes.get("nextAiring", "")

    @property
    def lastAiring(self):
        return self.attributes.get("lastAiring", "")

    @property
    def onWatchlist(self):
        return self.attributes.get("onWatchlist", True)

    @property
    def lastSeenAt(self):
        return self.attributes.get("lastSeenAt", None)

    @property
    def seen(self):
        return self.attributes.get("seen", True)

    @property
    def firstUnwatchedEpisode(self):
        return self.attributes.get("firstUnwatchedEpisode", "")

    @property
    def progress(self):
        return self.attributes.get("progress", None)

    @property
    def totalRuntime(self):
        return self.attributes.get("totalRuntime", None)


class Upcomingepisode(MediaTrackerBase):
    @property
    def id(self):
        return self.attributes.get("id", None)

    @property
    def title(self):
        return self.attributes.get("title", "")

    @property
    def description(self):
        return self.attributes.get("description", "")

    @property
    def episodeNumber(self):
        return self.attributes.get("episodeNumber", None)

    @property
    def seasonNumber(self):
        return self.attributes.get("seasonNumber", None)

    @property
    def releaseDate(self):
        return self.attributes.get("releaseDate", "")

    @property
    def tvShowId(self):
        return self.attributes.get("tvShowId", None)

    @property
    def seasonId(self):
        return self.attributes.get("seasonId", None)

    @property
    def tmdbId(self):
        return self.attributes.get("tmdbId", None)

    @property
    def imdbId(self):
        return self.attributes.get("imdbId", "")

    @property
    def runtime(self):
        return self.attributes.get("runtime", None)

    @property
    def seenHistory(self):
        return [Seenhistory(x) for x in self.attributes.get("seenHistory", [])]

    @property
    def userRating(self):
        return UpcomingepisodeUserrating(self.attributes.get("userRating", {}))

    @property
    def lastSeenAt(self):
        return self.attributes.get("lastSeenAt", None)

    @property
    def seasonAndEpisodeNumber(self):
        return self.attributes.get("seasonAndEpisodeNumber", None)

    @property
    def seen(self):
        return self.attributes.get("seen", True)

    @property
    def tvShow(self):
        return UpcomingepisodeTvshow(self.attributes.get("tvShow", {}))

    @property
    def isSpecialEpisode(self):
        return self.attributes.get("isSpecialEpisode", True)

    @property
    def tvdbId(self):
        return self.attributes.get("tvdbId", None)

    @property
    def traktId(self):
        return self.attributes.get("traktId", None)

    @property
    def onWatchlist(self):
        return self.attributes.get("onWatchlist", True)


class Seenhistory(MediaTrackerBase):
    @property
    def id(self):
        return self.attributes.get("id", None)

    @property
    def date(self):
        return self.attributes.get("date", None)

    @property
    def mediaItemId(self):
        return self.attributes.get("mediaItemId", None)

    @property
    def episodeId(self):
        return self.attributes.get("episodeId", None)

    @property
    def userId(self):
        return self.attributes.get("userId", None)

    @property
    def duration(self):
        return self.attributes.get("duration", None)


class LastairedepisodeUserrating(MediaTrackerBase):
    @property
    def id(self):
        return self.attributes.get("id", None)

    @property
    def mediaItemId(self):
        return self.attributes.get("mediaItemId", None)

    @property
    def date(self):
        return self.attributes.get("date", None)

    @property
    def userId(self):
        return self.attributes.get("userId", None)

    @property
    def rating(self):
        return self.attributes.get("rating", None)

    @property
    def review(self):
        return self.attributes.get("review", "")

    @property
    def episodeId(self):
        return self.attributes.get("episodeId", None)

    @property
    def seasonId(self):
        return self.attributes.get("seasonId", None)


class Seenhistory(MediaTrackerBase):
    @property
    def id(self):
        return self.attributes.get("id", None)

    @property
    def date(self):
        return self.attributes.get("date", None)

    @property
    def mediaItemId(self):
        return self.attributes.get("mediaItemId", None)

    @property
    def episodeId(self):
        return self.attributes.get("episodeId", None)

    @property
    def userId(self):
        return self.attributes.get("userId", None)

    @property
    def duration(self):
        return self.attributes.get("duration", None)


class LastairedepisodeTvshowUserrating(MediaTrackerBase):
    @property
    def id(self):
        return self.attributes.get("id", None)

    @property
    def mediaItemId(self):
        return self.attributes.get("mediaItemId", None)

    @property
    def date(self):
        return self.attributes.get("date", None)

    @property
    def userId(self):
        return self.attributes.get("userId", None)

    @property
    def rating(self):
        return self.attributes.get("rating", None)

    @property
    def review(self):
        return self.attributes.get("review", "")

    @property
    def episodeId(self):
        return self.attributes.get("episodeId", None)

    @property
    def seasonId(self):
        return self.attributes.get("seasonId", None)


class LastairedepisodeTvshow(MediaTrackerBase):
    @property
    def id(self):
        return self.attributes.get("id", None)

    @property
    def releaseDate(self):
        return self.attributes.get("releaseDate", "")

    @property
    def slug(self):
        return self.attributes.get("slug", "")

    @property
    def numberOfEpisodes(self):
        return self.attributes.get("numberOfEpisodes", None)

    @property
    def poster(self):
        return self.attributes.get("poster", "")

    @property
    def title(self):
        return self.attributes.get("title", "")

    @property
    def tmdbId(self):
        return self.attributes.get("tmdbId", None)

    @property
    def tvdbId(self):
        return self.attributes.get("tvdbId", None)

    @property
    def traktId(self):
        return self.attributes.get("traktId", None)

    @property
    def tvmazeId(self):
        return self.attributes.get("tvmazeId", None)

    @property
    def backdrop(self):
        return self.attributes.get("backdrop", "")

    @property
    def developer(self):
        return self.attributes.get("developer", "")

    @property
    def genres(self):
        return self.attributes.get("genres", [])

    @property
    def igdbId(self):
        return self.attributes.get("igdbId", None)

    @property
    def imdbId(self):
        return self.attributes.get("imdbId", "")

    @property
    def audibleId(self):
        return self.attributes.get("audibleId", "")

    @property
    def lastTimeUpdated(self):
        return self.attributes.get("lastTimeUpdated", None)

    @property
    def mediaType(self):
        return self.attributes.get("mediaType", "")

    @property
    def network(self):
        return self.attributes.get("network", "")

    @property
    def numberOfSeasons(self):
        return self.attributes.get("numberOfSeasons", None)

    @property
    def openlibraryId(self):
        return self.attributes.get("openlibraryId", "")

    @property
    def originalTitle(self):
        return self.attributes.get("originalTitle", "")

    @property
    def overview(self):
        return self.attributes.get("overview", "")

    @property
    def platform(self):
        return self.attributes.get("platform", [])

    @property
    def tmdbRating(self):
        return self.attributes.get("tmdbRating", None)

    @property
    def runtime(self):
        return self.attributes.get("runtime", None)

    @property
    def source(self):
        return self.attributes.get("source", "")

    @property
    def status(self):
        return self.attributes.get("status", "")

    @property
    def url(self):
        return self.attributes.get("url", "")

    @property
    def needsDetails(self):
        return self.attributes.get("needsDetails", True)

    @property
    def authors(self):
        return self.attributes.get("authors", [])

    @property
    def narrators(self):
        return self.attributes.get("narrators", [])

    @property
    def language(self):
        return self.attributes.get("language", "")

    @property
    def goodreadsId(self):
        return self.attributes.get("goodreadsId", None)

    @property
    def numberOfPages(self):
        return self.attributes.get("numberOfPages", None)

    @property
    def audibleCountryCode(self):
        return self.attributes.get("audibleCountryCode", "")

    @property
    def isSearchResult(self):
        return self.attributes.get("isSearchResult", True)

    @property
    def hasDetails(self):
        return self.attributes.get("hasDetails", True)

    @property
    def posterSmall(self):
        return self.attributes.get("posterSmall", "")

    @property
    def seenHistory(self):
        return [Seenhistory(x) for x in self.attributes.get("seenHistory", [])]

    @property
    def unseenEpisodesCount(self):
        return self.attributes.get("unseenEpisodesCount", None)

    @property
    def userRating(self):
        return LastairedepisodeTvshowUserrating(self.attributes.get("userRating", {}))

    @property
    def upcomingEpisode(self):
        return self.attributes.get("upcomingEpisode", "")

    @property
    def lastAiredEpisode(self):
        return self.attributes.get("lastAiredEpisode", "")

    @property
    def nextAiring(self):
        return self.attributes.get("nextAiring", "")

    @property
    def lastAiring(self):
        return self.attributes.get("lastAiring", "")

    @property
    def onWatchlist(self):
        return self.attributes.get("onWatchlist", True)

    @property
    def lastSeenAt(self):
        return self.attributes.get("lastSeenAt", None)

    @property
    def seen(self):
        return self.attributes.get("seen", True)

    @property
    def firstUnwatchedEpisode(self):
        return self.attributes.get("firstUnwatchedEpisode", "")

    @property
    def progress(self):
        return self.attributes.get("progress", None)

    @property
    def totalRuntime(self):
        return self.attributes.get("totalRuntime", None)


class Lastairedepisode(MediaTrackerBase):
    @property
    def id(self):
        return self.attributes.get("id", None)

    @property
    def title(self):
        return self.attributes.get("title", "")

    @property
    def description(self):
        return self.attributes.get("description", "")

    @property
    def episodeNumber(self):
        return self.attributes.get("episodeNumber", None)

    @property
    def seasonNumber(self):
        return self.attributes.get("seasonNumber", None)

    @property
    def releaseDate(self):
        return self.attributes.get("releaseDate", "")

    @property
    def tvShowId(self):
        return self.attributes.get("tvShowId", None)

    @property
    def seasonId(self):
        return self.attributes.get("seasonId", None)

    @property
    def tmdbId(self):
        return self.attributes.get("tmdbId", None)

    @property
    def imdbId(self):
        return self.attributes.get("imdbId", "")

    @property
    def runtime(self):
        return self.attributes.get("runtime", None)

    @property
    def seenHistory(self):
        return [Seenhistory(x) for x in self.attributes.get("seenHistory", [])]

    @property
    def userRating(self):
        return LastairedepisodeUserrating(self.attributes.get("userRating", {}))

    @property
    def lastSeenAt(self):
        return self.attributes.get("lastSeenAt", None)

    @property
    def seasonAndEpisodeNumber(self):
        return self.attributes.get("seasonAndEpisodeNumber", None)

    @property
    def seen(self):
        return self.attributes.get("seen", True)

    @property
    def tvShow(self):
        return LastairedepisodeTvshow(self.attributes.get("tvShow", {}))

    @property
    def isSpecialEpisode(self):
        return self.attributes.get("isSpecialEpisode", True)

    @property
    def tvdbId(self):
        return self.attributes.get("tvdbId", None)

    @property
    def traktId(self):
        return self.attributes.get("traktId", None)

    @property
    def onWatchlist(self):
        return self.attributes.get("onWatchlist", True)


class Seenhistory(MediaTrackerBase):
    @property
    def id(self):
        return self.attributes.get("id", None)

    @property
    def date(self):
        return self.attributes.get("date", None)

    @property
    def mediaItemId(self):
        return self.attributes.get("mediaItemId", None)

    @property
    def episodeId(self):
        return self.attributes.get("episodeId", None)

    @property
    def userId(self):
        return self.attributes.get("userId", None)

    @property
    def duration(self):
        return self.attributes.get("duration", None)


class FirstunwatchedepisodeUserrating(MediaTrackerBase):
    @property
    def id(self):
        return self.attributes.get("id", None)

    @property
    def mediaItemId(self):
        return self.attributes.get("mediaItemId", None)

    @property
    def date(self):
        return self.attributes.get("date", None)

    @property
    def userId(self):
        return self.attributes.get("userId", None)

    @property
    def rating(self):
        return self.attributes.get("rating", None)

    @property
    def review(self):
        return self.attributes.get("review", "")

    @property
    def episodeId(self):
        return self.attributes.get("episodeId", None)

    @property
    def seasonId(self):
        return self.attributes.get("seasonId", None)


class Seenhistory(MediaTrackerBase):
    @property
    def id(self):
        return self.attributes.get("id", None)

    @property
    def date(self):
        return self.attributes.get("date", None)

    @property
    def mediaItemId(self):
        return self.attributes.get("mediaItemId", None)

    @property
    def episodeId(self):
        return self.attributes.get("episodeId", None)

    @property
    def userId(self):
        return self.attributes.get("userId", None)

    @property
    def duration(self):
        return self.attributes.get("duration", None)


class FirstunwatchedepisodeTvshowUserrating(MediaTrackerBase):
    @property
    def id(self):
        return self.attributes.get("id", None)

    @property
    def mediaItemId(self):
        return self.attributes.get("mediaItemId", None)

    @property
    def date(self):
        return self.attributes.get("date", None)

    @property
    def userId(self):
        return self.attributes.get("userId", None)

    @property
    def rating(self):
        return self.attributes.get("rating", None)

    @property
    def review(self):
        return self.attributes.get("review", "")

    @property
    def episodeId(self):
        return self.attributes.get("episodeId", None)

    @property
    def seasonId(self):
        return self.attributes.get("seasonId", None)


class FirstunwatchedepisodeTvshow(MediaTrackerBase):
    @property
    def id(self):
        return self.attributes.get("id", None)

    @property
    def releaseDate(self):
        return self.attributes.get("releaseDate", "")

    @property
    def slug(self):
        return self.attributes.get("slug", "")

    @property
    def numberOfEpisodes(self):
        return self.attributes.get("numberOfEpisodes", None)

    @property
    def poster(self):
        return self.attributes.get("poster", "")

    @property
    def title(self):
        return self.attributes.get("title", "")

    @property
    def tmdbId(self):
        return self.attributes.get("tmdbId", None)

    @property
    def tvdbId(self):
        return self.attributes.get("tvdbId", None)

    @property
    def traktId(self):
        return self.attributes.get("traktId", None)

    @property
    def tvmazeId(self):
        return self.attributes.get("tvmazeId", None)

    @property
    def backdrop(self):
        return self.attributes.get("backdrop", "")

    @property
    def developer(self):
        return self.attributes.get("developer", "")

    @property
    def genres(self):
        return self.attributes.get("genres", [])

    @property
    def igdbId(self):
        return self.attributes.get("igdbId", None)

    @property
    def imdbId(self):
        return self.attributes.get("imdbId", "")

    @property
    def audibleId(self):
        return self.attributes.get("audibleId", "")

    @property
    def lastTimeUpdated(self):
        return self.attributes.get("lastTimeUpdated", None)

    @property
    def mediaType(self):
        return self.attributes.get("mediaType", "")

    @property
    def network(self):
        return self.attributes.get("network", "")

    @property
    def numberOfSeasons(self):
        return self.attributes.get("numberOfSeasons", None)

    @property
    def openlibraryId(self):
        return self.attributes.get("openlibraryId", "")

    @property
    def originalTitle(self):
        return self.attributes.get("originalTitle", "")

    @property
    def overview(self):
        return self.attributes.get("overview", "")

    @property
    def platform(self):
        return self.attributes.get("platform", [])

    @property
    def tmdbRating(self):
        return self.attributes.get("tmdbRating", None)

    @property
    def runtime(self):
        return self.attributes.get("runtime", None)

    @property
    def source(self):
        return self.attributes.get("source", "")

    @property
    def status(self):
        return self.attributes.get("status", "")

    @property
    def url(self):
        return self.attributes.get("url", "")

    @property
    def needsDetails(self):
        return self.attributes.get("needsDetails", True)

    @property
    def authors(self):
        return self.attributes.get("authors", [])

    @property
    def narrators(self):
        return self.attributes.get("narrators", [])

    @property
    def language(self):
        return self.attributes.get("language", "")

    @property
    def goodreadsId(self):
        return self.attributes.get("goodreadsId", None)

    @property
    def numberOfPages(self):
        return self.attributes.get("numberOfPages", None)

    @property
    def audibleCountryCode(self):
        return self.attributes.get("audibleCountryCode", "")

    @property
    def isSearchResult(self):
        return self.attributes.get("isSearchResult", True)

    @property
    def hasDetails(self):
        return self.attributes.get("hasDetails", True)

    @property
    def posterSmall(self):
        return self.attributes.get("posterSmall", "")

    @property
    def seenHistory(self):
        return [Seenhistory(x) for x in self.attributes.get("seenHistory", [])]

    @property
    def unseenEpisodesCount(self):
        return self.attributes.get("unseenEpisodesCount", None)

    @property
    def userRating(self):
        return FirstunwatchedepisodeTvshowUserrating(
            self.attributes.get("userRating", {})
        )

    @property
    def upcomingEpisode(self):
        return self.attributes.get("upcomingEpisode", "")

    @property
    def lastAiredEpisode(self):
        return self.attributes.get("lastAiredEpisode", "")

    @property
    def nextAiring(self):
        return self.attributes.get("nextAiring", "")

    @property
    def lastAiring(self):
        return self.attributes.get("lastAiring", "")

    @property
    def onWatchlist(self):
        return self.attributes.get("onWatchlist", True)

    @property
    def lastSeenAt(self):
        return self.attributes.get("lastSeenAt", None)

    @property
    def seen(self):
        return self.attributes.get("seen", True)

    @property
    def firstUnwatchedEpisode(self):
        return self.attributes.get("firstUnwatchedEpisode", "")

    @property
    def progress(self):
        return self.attributes.get("progress", None)

    @property
    def totalRuntime(self):
        return self.attributes.get("totalRuntime", None)


class Firstunwatchedepisode(MediaTrackerBase):
    @property
    def id(self):
        return self.attributes.get("id", None)

    @property
    def title(self):
        return self.attributes.get("title", "")

    @property
    def description(self):
        return self.attributes.get("description", "")

    @property
    def episodeNumber(self):
        return self.attributes.get("episodeNumber", None)

    @property
    def seasonNumber(self):
        return self.attributes.get("seasonNumber", None)

    @property
    def releaseDate(self):
        return self.attributes.get("releaseDate", "")

    @property
    def tvShowId(self):
        return self.attributes.get("tvShowId", None)

    @property
    def seasonId(self):
        return self.attributes.get("seasonId", None)

    @property
    def tmdbId(self):
        return self.attributes.get("tmdbId", None)

    @property
    def imdbId(self):
        return self.attributes.get("imdbId", "")

    @property
    def runtime(self):
        return self.attributes.get("runtime", None)

    @property
    def seenHistory(self):
        return [Seenhistory(x) for x in self.attributes.get("seenHistory", [])]

    @property
    def userRating(self):
        return FirstunwatchedepisodeUserrating(self.attributes.get("userRating", {}))

    @property
    def lastSeenAt(self):
        return self.attributes.get("lastSeenAt", None)

    @property
    def seasonAndEpisodeNumber(self):
        return self.attributes.get("seasonAndEpisodeNumber", None)

    @property
    def seen(self):
        return self.attributes.get("seen", True)

    @property
    def tvShow(self):
        return FirstunwatchedepisodeTvshow(self.attributes.get("tvShow", {}))

    @property
    def isSpecialEpisode(self):
        return self.attributes.get("isSpecialEpisode", True)

    @property
    def tvdbId(self):
        return self.attributes.get("tvdbId", None)

    @property
    def traktId(self):
        return self.attributes.get("traktId", None)

    @property
    def onWatchlist(self):
        return self.attributes.get("onWatchlist", True)


class Lists(MediaTrackerBase):
    @property
    def id(self):
        return self.attributes.get("id", None)

    @property
    def name(self):
        return self.attributes.get("name", "")

    @property
    def slug(self):
        return self.attributes.get("slug", "")

    @property
    def description(self):
        return self.attributes.get("description", "")

    @property
    def privacy(self):
        return self.attributes.get("privacy", "")

    @property
    def sortBy(self):
        return self.attributes.get("sortBy", "")

    @property
    def sortOrder(self):
        return self.attributes.get("sortOrder", "")

    @property
    def createdAt(self):
        return self.attributes.get("createdAt", None)

    @property
    def updatedAt(self):
        return self.attributes.get("updatedAt", None)

    @property
    def userId(self):
        return self.attributes.get("userId", None)

    @property
    def rank(self):
        return self.attributes.get("rank", None)

    @property
    def allowComments(self):
        return self.attributes.get("allowComments", True)

    @property
    def displayNumbers(self):
        return self.attributes.get("displayNumbers", True)

    @property
    def isWatchlist(self):
        return self.attributes.get("isWatchlist", True)

    @property
    def traktId(self):
        return self.attributes.get("traktId", None)


class MediaTrackerItem(MediaTrackerBaseClient):
    @property
    def id(self):
        return self.attributes.get("id", None)

    @property
    def releaseDate(self):
        return self.attributes.get("releaseDate", "")

    @property
    def slug(self):
        return self.attributes.get("slug", "")

    @property
    def numberOfEpisodes(self):
        return self.attributes.get("numberOfEpisodes", None)

    @property
    def poster(self):
        return self.attributes.get("poster", "")

    @property
    def title(self):
        return self.attributes.get("title", "")

    @property
    def tmdbId(self):
        return self.attributes.get("tmdbId", None)

    @property
    def tvdbId(self):
        return self.attributes.get("tvdbId", None)

    @property
    def traktId(self):
        return self.attributes.get("traktId", None)

    @property
    def tvmazeId(self):
        return self.attributes.get("tvmazeId", None)

    @property
    def backdrop(self):
        return self.attributes.get("backdrop", "")

    @property
    def developer(self):
        return self.attributes.get("developer", "")

    @property
    def genres(self):
        return self.attributes.get("genres", [])

    @property
    def igdbId(self):
        return self.attributes.get("igdbId", None)

    @property
    def imdbId(self):
        return self.attributes.get("imdbId", "")

    @property
    def audibleId(self):
        return self.attributes.get("audibleId", "")

    @property
    def lastTimeUpdated(self):
        return self.attributes.get("lastTimeUpdated", None)

    @property
    def mediaType(self):
        return self.attributes.get("mediaType", "")

    @property
    def network(self):
        return self.attributes.get("network", "")

    @property
    def numberOfSeasons(self):
        return self.attributes.get("numberOfSeasons", None)

    @property
    def openlibraryId(self):
        return self.attributes.get("openlibraryId", "")

    @property
    def originalTitle(self):
        return self.attributes.get("originalTitle", "")

    @property
    def overview(self):
        return self.attributes.get("overview", "")

    @property
    def platform(self):
        return self.attributes.get("platform", [])

    @property
    def tmdbRating(self):
        return self.attributes.get("tmdbRating", None)

    @property
    def runtime(self):
        return self.attributes.get("runtime", None)

    @property
    def source(self):
        return self.attributes.get("source", "")

    @property
    def status(self):
        return self.attributes.get("status", "")

    @property
    def url(self):
        return self.attributes.get("url", "")

    @property
    def needsDetails(self):
        return self.attributes.get("needsDetails", True)

    @property
    def authors(self):
        return self.attributes.get("authors", [])

    @property
    def narrators(self):
        return self.attributes.get("narrators", [])

    @property
    def language(self):
        return self.attributes.get("language", "")

    @property
    def goodreadsId(self):
        return self.attributes.get("goodreadsId", None)

    @property
    def numberOfPages(self):
        return self.attributes.get("numberOfPages", None)

    @property
    def audibleCountryCode(self):
        return self.attributes.get("audibleCountryCode", "")

    @property
    def seasons(self):
        return [Seasons(x) for x in self.attributes.get("seasons", [])]

    @property
    def isSearchResult(self):
        return self.attributes.get("isSearchResult", True)

    @property
    def hasDetails(self):
        return self.attributes.get("hasDetails", True)

    @property
    def posterSmall(self):
        return self.attributes.get("posterSmall", "")

    @property
    def seenHistory(self):
        return [Seenhistory(x) for x in self.attributes.get("seenHistory", [])]

    @property
    def unseenEpisodesCount(self):
        return self.attributes.get("unseenEpisodesCount", None)

    @property
    def userRating(self):
        return Userrating(self.attributes.get("userRating", {}))

    @property
    def upcomingEpisode(self):
        return Upcomingepisode(self.attributes.get("upcomingEpisode", {}))

    @property
    def lastAiredEpisode(self):
        return Lastairedepisode(self.attributes.get("lastAiredEpisode", {}))

    @property
    def nextAiring(self):
        return self.attributes.get("nextAiring", "")

    @property
    def lastAiring(self):
        return self.attributes.get("lastAiring", "")

    @property
    def onWatchlist(self):
        return self.attributes.get("onWatchlist", True)

    @property
    def lastSeenAt(self):
        return self.attributes.get("lastSeenAt", None)

    @property
    def seen(self):
        return self.attributes.get("seen", True)

    @property
    def firstUnwatchedEpisode(self):
        return Firstunwatchedepisode(self.attributes.get("firstUnwatchedEpisode", {}))

    @property
    def progress(self):
        return self.attributes.get("progress", None)

    @property
    def totalRuntime(self):
        return self.attributes.get("totalRuntime", None)

    @property
    def lists(self):
        return [Lists(x) for x in self.attributes.get("lists", [])]



"""MediaTracker: Base"""
import logging


class MediaTrackerBase:
    """Base class for MediaTracker."""

    logger = logging.getLogger(__name__)

    def __init__(self, attributes) -> None:
        """Initialize."""
        self.attributes = attributes


class MediaTrackerBaseClient(MediaTrackerBase):
    """Base class for MediaTracker."""

    def __init__(self, client, attributes: dict) -> None:
        """Initialise."""
        super().__init__(attributes)
        self.client = client



"""MediaTracker: Api"""
import logging
from asyncio import get_event_loop
import async_timeout

from aiohttp import ClientSession, ClientResponse

from .exceptions import MediaTrackerException


class MediaTrackerClient:
    """Connection to MediaTracker API."""

    def __init__(self, session: ClientSession) -> None:
        """Initialize."""
        self._session = session

    async def get(self, url: str, **kwargs) -> ClientResponse:
        """Make a GET request."""
        return await self.request("GET", url, **kwargs)

    async def post(self, url: str, **kwargs) -> ClientResponse:
        """Make a POST request."""
        return await self.request("POST", url, **kwargs)

    async def request(self, method, url, **kwargs) -> ClientResponse:
        """Make a request."""
        headers = kwargs.get("headers")

        if headers is None:
            headers = {}
        else:
            headers = dict(headers)

        headers["Content-Type"] = "application/json"

        async with async_timeout.timeout(20, loop=get_event_loop()):
            response: ClientResponse = await self._session.request(
                method,
                url,
                headers=headers,
                **kwargs,
            )
        if response.status != 200:
            raise MediaTrackerException(
                {
                    "request": {
                        "method": method,
                        "url": url,
                        "headers": headers,
                        **kwargs,
                    },
                    "response": await response.json(),
                    "status": response.status,
                }
            )
        return response



"""
Class object for MediaTrackerConfig
Documentation:

Generated by generator/generator.py - 2023-05-09 14:40:06.285643
"""
from .base import MediaTrackerBaseClient


class MediaTrackerConfig(MediaTrackerBaseClient):
    @property
    def enableRegistration(self):
        return self.attributes.get("enableRegistration", True)

    @property
    def tmdbLang(self):
        return self.attributes.get("tmdbLang", "")

    @property
    def audibleLang(self):
        return self.attributes.get("audibleLang", "")

    @property
    def serverLang(self):
        return self.attributes.get("serverLang", "")

    @property
    def igdbClientId(self):
        return self.attributes.get("igdbClientId", "")

    @property
    def igdbClientSecret(self):
        return self.attributes.get("igdbClientSecret", "")

    @property
    def noUsers(self):
        return self.attributes.get("noUsers", False)

    @property
    def demo(self):
        return self.attributes.get("demo", False)

    @property
    def version(self):
        return self.attributes.get("version", "")
